@@ -131,11 +131,19 @@ macro_rules! impl_mixed_num_for_fixed_unsigned{
         impl_mixed_num_for_fixed!($T);
 
         impl MixedOps for $T
+        {
+        }
+
+        impl MixedAbs for $T
         {
             #[inline(always)]
             fn mixed_abs( &self ) -> Self {
                 return *self; // Is itself for unsigned.
             }
+        }
+
+        impl MixedPowi for $T
+        {
             #[inline(always)]
             fn mixed_powi( &self, exp: i32 ) -> Self {
                 return trigonometry::powi( *self, exp as usize );
@@ -177,11 +185,19 @@ macro_rules! impl_mixed_num_for_fixed_signed{
         }
 
         impl MixedOps for $T
+        {
+        }
+
+        impl MixedAbs for $T
         {
             #[inline(always)]
             fn mixed_abs( &self ) -> Self {
                 return self.abs();
             }
+        }
+
+        impl MixedPowi for $T
+        {
             #[inline(always)]
             fn mixed_powi( &self, exp: i32 ) -> Self {
                 return trigonometry::powi( *self, exp as usize );
